@@ -455,8 +455,6 @@ class OWFeatureConstructor(OWWidget):
         box.layout().addLayout(layout, 1)
 
         box = gui.hBox(self.controlArea)
-        box.layout().addWidget(self.report_button)
-        self.report_button.setMinimumWidth(180)
         gui.rubber(box)
         commit = gui.button(box, self, "Send", callback=self.apply,
                             default=True)
