@@ -459,6 +459,63 @@ class TestOWScatterPlot(WidgetTest, WidgetOutputsTestMixin):
         self.assertEqual(attr_y.currentText(), breathes.name)
         self.assertEqual(attr_color.currentText(), type.name)
 
+    def test_handle_metas(self):
+        """
+        Scatter Plot Graph can handle metas
+        GH-2699
+        """
+        w = self.widget
+        data = Table("iris")
+        domain = Domain(
+            attributes=data.domain.attributes[:2],
+            class_vars=data.domain.class_vars,
+            metas=data.domain.attributes[2:]
+        )
+        data = data.transform(domain)
+        # Sometimes floats in metas are saved as objects
+        data.metas = data.metas.astype(object)
+        self.send_signal(w.Inputs.data, data)
+        simulate.combobox_activate_item(w.cb_attr_x, data.domain.metas[1].name)
+        simulate.combobox_activate_item(w.controls.graph.attr_color, data.domain.metas[0].name)
+        w.update_graph()
+
+    def test_subset_data(self):
+        """
+        Scatter Plot subset data is sent to Scatter Plot Graph
+        GH-2773
+        """
+        data = Table("iris")
+        w = self.widget
+        self.send_signal(w.Inputs.data, data)
+        self.send_signal(w.Inputs.data_subset, data[::30])
+        self.assertEqual(len(w.graph.subset_indices), 5)
+
+    def test_sparse_subset_data(self):
+        """
+        Scatter Plot can handle sparse subset data.
+        GH-2773
+        """
+        data = Table("iris")
+        w = self.widget
+        data.X = sp.csr_matrix(data.X)
+        self.send_signal(w.Inputs.data, data)
+        self.send_signal(w.Inputs.data_subset, data[::30])
+        self.assertEqual(len(w.graph.subset_indices), 5)
+
+    def test_metas_zero_column(self):
+        """
+        Prevent crash when metas column is zero.
+        GH-2775
+        """
+        data = Table("iris")
+        domain = data.domain
+        domain = Domain(domain.attributes[:3], domain.class_vars, domain.attributes[3:])
+        data = data.transform(domain)
+        data.metas[:, 0] = 0
+        w = self.widget
+        self.send_signal(w.Inputs.data, data)
+        simulate.combobox_activate_item(w.controls.attr_x, domain.metas[0].name)
+
 
 if __name__ == "__main__":
     import unittest
